import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
import java.util.List;

/**
 * A proton wave that expands and destroys things in its path.
 * 
 * @author Michael Kolling
 * @version 0.1
 */
public class ProtonWave extends Actor
{
    /** The damage this wave will deal */
    private static final int DAMAGE = 30;

    /** How many images should be used in the animation of the wave */
    private static final int NUMBER_IMAGES= 30;

    private int imageCount;

    /** 
     * The images of the wave. This is static so the images are not
     * recreated for every object (improves performance significantly).
     */
    private static GreenfootImage[] images;

    /**
     * Create a new proton wave.
     */
    public ProtonWave() 
    {
        initializeImages();
        setImage(images[0]);
        Greenfoot.playSound("proton.wav");
        imageCount = 0;
    }

    /** 
     * Create the images for expanding the wave.
     */
    public static void initializeImages() 
    {
        if(images == null) 
        {
            GreenfootImage baseImage = new GreenfootImage("wave.png");
            images = new GreenfootImage[NUMBER_IMAGES];
            int i = 0;
            while (i < NUMBER_IMAGES) 
            {
                int size = (i+1) * ( baseImage.getWidth() / NUMBER_IMAGES );
                images[i] = new GreenfootImage(baseImage);
                images[i].scale(size, size);
                i++;
            }
        }
    }

    /**
     * Increases the size of the proton wave
     */
    public void grow()
    {
        setImage(images[imageCount]);
        imageCount++;
        if(imageCount >=30)
            getWorld().removeObject(this);
    }

    /**
     * Act for the proton wave is: grow and check whether we hit anything.
     */
    public void act()
    {
        destroyAsteroids();
        grow();
    }
    
    /**
     * Removes Asteroids inside the protonwave
     */
    public void destroyAsteroids()
    {
        int range = getImage().getWidth()/2;
        List<Asteroid> list = getObjectsInRange(range,Asteroid.class);
        
        for(Asteroid a:list)
        {
            a.hit(16);
        }
    }

}
