import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
import java.awt.Color;

/**
 * Space. Something for rockets to fly in.
 * 
 * @author Michael Kolling
 * @version 1.0
 */
public class Space extends World
{
    private Counter scoreCounter;
    private int startAsteroids = 1;

    private ProtonTimer[] bars = new ProtonTimer[5];

    public Counter score;
    public int level;
    public Counter levelCounter;
    public ShieldCounter shieldC;

    private Rocket r;

    public Space() 
    {
        super(600, 400, 1);
        GreenfootImage background = getBackground();
        background.setColor(Color.BLACK);
        background.fill();

        createStars(300);
        Rocket rocket = new Rocket();
        addObject(rocket, getWidth()/2 + 100, getHeight()/2);
        this.r = rocket;

        level = 1;

        addAsteroids(startAsteroids);

        scoreCounter = new Counter("Score: ");
        this.score = scoreCounter;
        addObject(scoreCounter, 60, 380);

        Counter lCounter = new Counter("Level: ");
        lCounter.add(1);
        this.levelCounter = lCounter;
        addObject(lCounter,120,380);
        
         ShieldCounter sh = new ShieldCounter();
        shieldC = sh;
        addObject(sh, 580,200);

        Explosion.initializeImages();
        ProtonWave.initializeImages();

        createProtonCounter();

    }
    /**
     * Add a given number of asteroids to our world. Asteroids are only added into
     * the left half of the world.
     */
    private void addAsteroids(int count) 
    {
        int astroidRadius = 25;
        for(int i = 0; i < count; i++) 
        {
            int x = Greenfoot.getRandomNumber(getWidth()/2);
            int y = Greenfoot.getRandomNumber(getHeight()/2);

            addObject(new Asteroid(this), x, y);
        }
    }

    /**
     * This method is called when the game is over to display the final score.
     */
    public void gameOver() 
    {
        ScoreBoard sb = new ScoreBoard(score.getValue());
        int w = (getWidth()/2);
        int h = (getHeight()/2);
        addObject(sb,w,h);
    }

    /**
     * Creates stars on screen
     */
    public void createStars(int number)
    {
        GreenfootImage background = getBackground();
        for(int n=0; n<number;n++)
        {
            int randX = Greenfoot.getRandomNumber(600);
            int randY = Greenfoot.getRandomNumber(400);

            int randBright = Greenfoot.getRandomNumber(255);
            Color randColor = new Color(randBright,randBright,randBright);
            background.setColor(randColor);
            background.fillOval(randX,randY,2,2);

        }
    }

    /**
     * Starts the next Level
     */
    public void nextLevel()
    {
        Greenfoot.playSound("victory.wav");
        level++;
        levelCounter.add(1);
        startAsteroids++;
        r.resetLocation();
        addAsteroids(startAsteroids);

    }

    /**
     * CReates the value
     */
    public void createProtonCounter()
    {
        int yVal = 390;
        for(int i=0; i<bars.length;i++)
        {
            ProtonTimer box = new ProtonTimer();
            box.setOn(false);
            bars[i] = box;
            addObject(box,580,yVal);
            yVal = yVal - 10;
        }
    }

    /**
     * Tells the bars to turn green or red
     */
    public void updateTimer(int delay,int count)
    {
        double temp = 5*count/delay;
        int bar = (int)temp - 1;
        for(int i=0; i<=bar;i++)
        {

            bars[i].setOn(true);
        }
    }

    /**
     * 
     */
    public void protonWaveUsed()
    {
        for(int i=0; i<bars.length;i++)
        {
            bars[i].setOn(false);
        }
    }
    
    public void resetShieldMeter(int level)
    {
        shieldC.resetMeter(level);
    }
}

